From: Mike Travis <travis@sgi.com>
To: Ingo Molnar <mingo@elte.hu>
Cc: Andi Kleen <andi@firstfloor.org>, Pavel Machek <pavel@suse.cz>,
Rusty Russell <rusty@rustcorp.com.au>,
Andrew Morton <akpm@linux-foundation.org>,
Thomas Gleixner <tglx@linutronix.de>,
Jack Steiner <steiner@sgi.com>, "H. Peter Anvin" <hpa@zytor.com>,
Richard Purdie <rpurdie@rpsys.net>,
LKML <linux-kernel@vger.kernel.org>
Subject: [PATCH 1/1] SGI x86 UV: Update SCIR driver to use idle_cpu function
Date: Mon, 27 Oct 2008 07:51:20 -0700 [thread overview]
Message-ID: <4905D568.20701@sgi.com> (raw)
In-Reply-To: <20081027114205.GB5631@elte.hu>
Subject: SGI x86 UV: Update SCIR driver to use idle_cpu function
> Please send the cpu_idle() cleanup patch separately.
Change UV heartbeat function to use idle_cpu to determine cpu's
"idleness". Realign uv_hub definitions.
Signed-of-by: Mike Travis <travis@sgi.com>
---
arch/x86/include/asm/uv/uv_hub.h | 26 +++++++++++++-------------
arch/x86/kernel/genx2apic_uv_x.c | 4 ++--
2 files changed, 15 insertions(+), 15 deletions(-)
--- test-tip-latest.orig/arch/x86/include/asm/uv/uv_hub.h
+++ test-tip-latest/arch/x86/include/asm/uv/uv_hub.h
@@ -128,19 +128,19 @@ struct uv_scir_s {
* They are kept together in a struct to minimize cache misses.
*/
struct uv_hub_info_s {
- unsigned long global_mmr_base;
- unsigned long gpa_mask;
- unsigned long gnode_upper;
- unsigned long lowmem_remap_top;
- unsigned long lowmem_remap_base;
- unsigned short pnode;
- unsigned short pnode_mask;
- unsigned short coherency_domain_number;
- unsigned short numa_blade_id;
- unsigned char blade_processor_id;
- unsigned char m_val;
- unsigned char n_val;
- struct uv_scir_s scir;
+ unsigned long global_mmr_base;
+ unsigned long gpa_mask;
+ unsigned long gnode_upper;
+ unsigned long lowmem_remap_top;
+ unsigned long lowmem_remap_base;
+ unsigned short pnode;
+ unsigned short pnode_mask;
+ unsigned short coherency_domain_number;
+ unsigned short numa_blade_id;
+ unsigned char blade_processor_id;
+ unsigned char m_val;
+ unsigned char n_val;
+ struct uv_scir_s scir;
};
DECLARE_PER_CPU(struct uv_hub_info_s, __uv_hub_info);
--- test-tip-latest.orig/arch/x86/kernel/genx2apic_uv_x.c
+++ test-tip-latest/arch/x86/kernel/genx2apic_uv_x.c
@@ -371,8 +371,8 @@ static void uv_heartbeat(unsigned long i
/* flip heartbeat bit */
bits ^= SCIR_CPU_HEARTBEAT;
- /* are we the idle thread? */
- if (current->pid == 0)
+ /* is this cpu idle? */
+ if (idle_cpu(smp_processor_id()))
bits &= ~SCIR_CPU_ACTIVITY;
else
bits |= SCIR_CPU_ACTIVITY;
next prev parent reply other threads:[~2008-10-27 14:50 UTC|newest]
Thread overview: 17+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-10-24 11:19 [PATCH 1/1] SGI X86 UV: Provide a System Activity Indicator driver Mike Travis
2008-10-24 12:01 ` Pavel Machek
2008-10-24 12:05 ` Ingo Molnar
2008-10-24 12:27 ` Mike Travis
2008-10-24 18:12 ` Andi Kleen
2008-10-24 22:18 ` Mike Travis
2008-10-24 22:24 ` Mike Travis
2008-10-27 11:42 ` Ingo Molnar
2008-10-27 14:38 ` Mike Travis
2008-10-27 14:51 ` Mike Travis [this message]
2008-10-27 18:06 ` [PATCH 1/1] SGI x86 UV: Update SCIR driver to use idle_cpu function Ingo Molnar
2008-10-27 18:46 ` [PATCH 1/1] SGI x86 UV: Use raw_smp_processor_id Mike Travis
2008-10-25 6:56 ` [PATCH 1/1] SGI X86 UV: Provide a System Activity Indicator driver Andi Kleen
2008-10-27 15:12 ` Mike Travis
2008-10-27 11:36 ` Ingo Molnar
2008-10-27 11:43 ` Ingo Molnar
2008-10-24 12:14 ` Mike Travis
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4905D568.20701@sgi.com \
--to=travis@sgi.com \
--cc=akpm@linux-foundation.org \
--cc=andi@firstfloor.org \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=mingo@elte.hu \
--cc=pavel@suse.cz \
--cc=rpurdie@rpsys.net \
--cc=rusty@rustcorp.com.au \
--cc=steiner@sgi.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.